@@ -37,6 +37,10 @@ _soya = sys.modules["soya._soya"]
 sys.modules["soyapyrex"] = _soya
 
 def set_root_widget(widget):
+  """set_root_widget(WIDGET)
+
+Sets the root widget to WIDGET. The root widget is the widget that is rendered first.
+It defaults to the first Camera you create."""
   global root_widget
   root_widget = widget
   _soya.set_root_widget(widget)
@@ -127,7 +131,7 @@ filename of the source that needs to be re-exported."""
             print "* Soya * Converting %s to %s..." % (source_file, klass.__name__)
             return source_dirname, source_file, file
           
-    raise ValueError("No %s or %s named %s" % (klass.__name__, source_dirname, filename))
+    raise ValueError("No %s or %s named %s" % (klass.__name__, source_dirnames, filename))
   _check_export = classmethod(_check_export)
   
   def get(klass, filename):
@@ -151,9 +155,12 @@ Raise ValueError if the file is not found in soya.path."""
       file = os.path.join(p, klass.DIRNAME, filename + ".data")
       if os.path.exists(file):
         obj = klass._alls[filename] = pickle.loads(open(file, "rb").read())
+        obj.loaded()
         return obj
     raise ValueError("No %s named %s" % (klass.__name__, filename))
   load = classmethod(load)
+
+  def loaded(self): pass
   
   def save(self, filename = None):
     """SavedInAPath.save(filename = None)
@@ -162,13 +169,15 @@ Saves this object. If no FILENAME is given, the object is saved in the path,
 using its filename attribute. If FILENAME is given, it is saved at this
 location."""
     global _SAVING
-    _SAVING = self # Hack !!
-    #pickle.dump(self, open(filename or os.path.join(path[0], self.DIRNAME, self.filename.replace("/", os.sep)) + ".data", "wb"), 1)
-    # Avoid destroying the file if the serialization causes an error.
-    data = pickle.dumps(self, 1)
-    open(filename or os.path.join(path[0], self.DIRNAME, self.filename.replace("/", os.sep)) + ".data", "wb").write(data)
-    _SAVING = None
-    
+    try:
+      _SAVING = self # Hack !!
+      #pickle.dump(self, open(filename or os.path.join(path[0], self.DIRNAME, self.filename.replace("/", os.sep)) + ".data", "wb"), 1)
+      # Avoid destroying the file if the serialization causes an error.
+      data = pickle.dumps(self, 1)
+      open(filename or os.path.join(path[0], self.DIRNAME, self.filename.replace("/", os.sep)) + ".data", "wb").write(data)
+    finally:
+      _SAVING = None
+      
   def __reduce__(self):
     if (not _SAVING is self) and self._filename: # self is saved in another file, save filename only
       if isinstance(self, CoordSyst): return (_loader, (self.__class__, self.filename)) # not shareable
@@ -273,6 +282,8 @@ Attributes are:
 
 - additive_blending: set it to true for additive blending. For semi-transparent surfaces
   (=alpha blended) only. Usefull for special effect (Ray, Sprite,...).
+
+- mip_map: set it to true to enable mipmaps for this materials texture. (default: True)
 """
 
   DIRNAME = "materials"
@@ -293,10 +304,18 @@ Attributes are:
         print "* Soya * WARNING : can't save material %s!" % filename
       return material
     else:
-      return pickle.loads(open(file, "rb").read())
+      obj = pickle.loads(open(file, "rb").read())
+      obj.loaded()
+      return obj
+
   load = classmethod(load)
   
 class Shape(SavedInAPath, _soya._Shape):
+  """Shape
+
+A Shape is an optimized model. Shapes cannot be modified, but they are rendered very
+quickly, and they can be used several time, e.g. if you want to 2 same cubes in a scene.
+Shapes are used in conjunction with Volume."""
   DIRNAME = "shapes"
   _alls = weakref.WeakValueDictionary()
   
@@ -311,7 +330,9 @@ class Shape(SavedInAPath, _soya._Shape):
         print "* Soya * WARNING : can't save compiled shape %s!" % filename
       return shape
     else:
-      return pickle.loads(open(file, "rb").read())
+      obj = pickle.loads(open(file, "rb").read())
+      obj.loaded()
+      return obj
   load = classmethod(load)
   
   def availables(klass): return World.availables()
@@ -319,13 +340,19 @@ class Shape(SavedInAPath, _soya._Shape):
   
   
 class SimpleShape(Shape, _soya._SimpleShape):
-  pass
+  """SimpleShape
+
+The most basic class of Shape."""
   
 class TreeShape(Shape, _soya._TreeShape):
-  pass
+  """TreeShape
+
+A Shape that use a BSP-like tree to optimize rendering and raypicking."""
 
 class CellShadingShape(Shape, _soya._CellShadingShape):
-  pass
+  """CellShadingShape
+
+A Shape that use cell-shading for rendering."""
 
 
 class Point(_soya._Point):
@@ -347,9 +374,9 @@ A Vertex doesn't display anything ; you MUST put it inside a Face.
 
 Attributes are (see also Point for inherited attributes):
 
-# - diffuse: the vertex diffuse color (also aliased to 'color' for compatibility)
-# - emissive: the vertex emissive color (lighting-independant color)
-# - tex_x, tex_y: the text
+ - diffuse: the vertex diffuse color (also aliased to 'color' for compatibility)
+ - emissive: the vertex emissive color (lighting-independant color)
+ - tex_x, tex_y: the text
 ure coordinates (sometime called U and V).
 """
   
@@ -387,8 +414,10 @@ Attributes are (see also Volume, CoordSyst and SavedInAPath for inherited attrib
 
  - children : the list of 3D object contained in the World (default to an empty list).
    use World.add(coordsyst) and World.remove(coordsyst) for additions and removals.
+
  - atmosphere : the atmosphere specifies atmospheric properties of the World (see
    Atmosphere). Default is None.
+
  - shapifier : the shapifier specifies how the World is compiled into Shape.
    Default is None, which result in the use of the default Shapifier, which is
    SimpleShapifier().
@@ -427,7 +456,9 @@ Attributes are (see also Volume, CoordSyst and SavedInAPath for inherited attrib
         world.save()
         return world
       
-    return pickle.loads(open(file, "rb").read())
+    obj = pickle.loads(open(file, "rb").read())
+    obj.loaded()
+    return obj
   load = classmethod(load)
   
 
@@ -467,13 +498,18 @@ Attributes are (see also CoordSyst and Widget for inherited attributes):
  - front, back : objects whose distance from the camera is not between front and back
    are clipped. Front defaults to 0.1 and back to 100.0.
    If the back / front ratio is too big, you loose precision in the depth buffer.
+
  - fov : the field of vision (or FOV), in degrees. Default is 60.0.
+
  - to_render : the world that is rendered by the camera. Default is None, which means
    the root scene (as returned by get_root()).
+
  - left, top, width, height : the viewport rectangle, in pixel. Use it if you want to
    render only on a part of the screen. It defaults to the whole screen.
+
  - ortho : True for orthogonal rendering, instead of perspective. Default is false.
- - partial : XXX ???.
+
+ - partial : XXX ???. probably DEPRECATED by NoBackgroundAtmosphere.
 """
 
 class Face(_soya._Face):
@@ -485,47 +521,119 @@ rendering them. To get a fast rendering, you should put several Faces in a World
 then compile the World into a Shape (see the modeling-X.py tutorial series).
 
 According to the number of Vertices, the result differs:
-- 1 Vertex => Plot
-- 2        => Line
-- 3        => Triangle
-- 4        => Quad
+ - 1 Vertex => Plot
+ - 2        => Line
+ - 3        => Triangle
+ - 4        => Quad
 
 All the vertices are expected to be coplannar.
 
 Interesting properties are:
 
-- vertices: the list of Vertices
-- material: the material used to draw the face's surface
-- double_sided: true if you want to see both sides of the Face. Default is false.
-- solid: true to enable the use of this Face for raypicking. Default is true.
-- lit: true to enable lighting on the Face. Default is true.
+ - vertices: the list of Vertices
+
+ - material: the material used to draw the face's surface
+
+ - double_sided: true if you want to see both sides of the Face. Default is false.
+
+ - solid: true to enable the use of this Face for raypicking. Default is true.
+
+ - lit: true to enable lighting on the Face. Default is true.
 
 The following options are used when compiling the Face into a Shape,
 but does not affect the rendering of the Face itself:
 
-- static_lit: true to enable static lighting (faster). If true, when compiling the Face
-  into a Shape, all Lights available will be applied as static lighting. Default is true.
-- smooth_lit: true to compute per-vertex normal vectors, instead of per-face normal vector.
-  This makes the Shape looking smooth (see tutorial modeling-smoothlit-1.py).
-  Notice that Soya automatically disable smooth_lit between 2 faces that makes a sharp
-  angle (see Shapifier.max_face_angle attribute).
-  Default is false.
+ - static_lit: true to enable static lighting (faster). If true, when compiling the Face
+   into a Shape, all Lights available will be applied as static lighting. Default is true.
+
+ - smooth_lit: true to compute per-vertex normal vectors, instead of per-face normal vector.
+   This makes the Shape looking smooth (see tutorial modeling-smoothlit-1.py).
+   Notice that Soya automatically disable smooth_lit between 2 faces that makes a sharp
+   angle (see Shapifier.max_face_angle attribute).
+   Default is false.
 """
 
 class Atmosphere(_soya._Atmosphere):
-  pass
+  """Atmosphere
+
+An Atmosphere is an object that defines all the atmospheric attributes of a World, such
+as fog, background or ambient lighting.
+
+To apply an Atmosphere to a World, as well as everything inside the World, do :
+
+    world.atmosphere = my_atmosphere
+
+You can safely put several Worlds one inside the other, with different Atmospheres.
+
+Attributes are :
+
+ - fog: true to activate fog, false to disable fog (default value).
+
+ - fog_color: the fog color (an (R, G, B, A) tuple of four floats). Defaults to black.
+
+ - fog_type: the type of fog. fog_type can take 3 different values :
+   - 0, linear fog: the fog range from fog_start to fog_end (default value).
+   - 1, exponentiel fog: the fog the fog increase exponentially to fog_density and the distance.
+   - 2, exponentiel squared fog: the fog the fog increase exponentially to the square of fog_density and the distance.
+
+ - fog_start: the distance at which the fog begins, if fog_type == 0. Defaults to 10.0.
+
+ - fog_end: the distance at which the fog ends, if fog_type == 0. Defaults to 100.0.
+
+ - fog_density: the fog density, if fog_type > 0. Defaults to 1.0.
+
+ - ambient: the ambient lighting color (an (R, G, B, A) tuple of four floats). Defaults to (0.5, 0.5, 0.5, 1.0).
+
+ - bg_color: the background color of the scene (an (R, G, B, A) tuple of four floats). Defaults to black.
+"""
 
 class NoBackgroundAtmosphere(_soya._NoBackgroundAtmosphere, Atmosphere):
-  pass
+  """NoBackgroundAtmosphere
+
+An Atmosphere with no background. It is usefull is you want to render a 3D scene over
+another 3D scene."""
 
 class SkyAtmosphere(_soya._SkyAtmosphere, Atmosphere):
-  pass
+  """SkyAtmosphere
+
+An Atmosphere with a skybox and/or a sky/cloud effect.
+
+In addition to those of Atmosphere, attributes are :
+
+ - sky_box: the sky box, a tuple of 5 or 6 materials that are displayed on the 6 faces of
+   the sky box (which is a cube). Use an empty tuple () to disable the sky box (default value).
+
+ - sky_color: the color of the sky (an (R, G, B, A) tuple of four floats).
+   Use a sky_color with an alpha component of 0.0 to disable cloud / sky effet.
+
+ - cloud: the cloud material, which is used to add a cloud-like effect to the sky.
+   Coulds move according to the camera.
+"""
 
 class Sprite(_soya._Sprite):
-  pass
+  """Sprite
 
+A 2D sprite, displayed as a 3D (e.g. think to very old 3D games).
+Today, sprite are usefull for special effect like explosion, or halo.
+The Sprite 2D texture always points toward the camera.
+
+Attributes are :
+
+ - material: the material of the Sprite, including the texture.
+
+ - color: the color of the Sprite (defaults to white).
+
+ - width and height: the size of the Sprite, in 3D coordinates values (not pixel values).
+   Both defaults to 0.5.
+
+ - lit: if true (default), lighting affects the sprite, and if false, it doesn't."""
+  
 class CylinderSprite(_soya._CylinderSprite, Sprite):
-  pass
+  """CylinderSprite
+
+A special kind of Sprite, that points toward the camera only in X and Z dimension, but
+not Y. This is usefull e.g. for lightening spell effects, for which using a normal Sprite
+would give a poor rendering if seen from top."""
 
 class Particles(_soya._Particles):
   pass
