@@ -24,9 +24,9 @@
 #include <windows.h>
 
 void init_advanced_opengl() {
-  glActiveTexture    = (PFNGLACTIVETEXTUREARBPROC   ) wglGetProcAddress("glActiveTextureARB"   );
-  glMultiTexCoord2fv = (PFNGLMULTITEXCOORD2FVARBPROC) wglGetProcAddress("glMultiTexCoord2fvARB");
-  glMultiTexCoord2f  = (PFNGLMULTITEXCOORD2FARBPROC ) wglGetProcAddress("glMultiTexCoord2fARB" );
+  glActiveTextureARB    = (PFNGLACTIVETEXTUREARBPROC   ) wglGetProcAddress("glActiveTextureARB"   );
+  glMultiTexCoord2fvARB = (PFNGLMULTITEXCOORD2FVARBPROC) wglGetProcAddress("glMultiTexCoord2fvARB");
+  glMultiTexCoord2fARB  = (PFNGLMULTITEXCOORD2FARBPROC ) wglGetProcAddress("glMultiTexCoord2fARB" );
 }
 
 
