@@ -24,9 +24,9 @@
 #define GL_TEXTURE_BINDING_3D           0x806A
 #define GL_POST_COLOR_MATRIX_ALPHA_BIAS 0x80BB
 
-PFNGLMULTITEXCOORD2FARBPROC  glMultiTexCoord2f ;
-PFNGLMULTITEXCOORD2FVARBPROC glMultiTexCoord2fv;
-PFNGLACTIVETEXTUREARBPROC    glActiveTexture   ;
+PFNGLMULTITEXCOORD2FARBPROC  glMultiTexCoord2fARB ;
+PFNGLMULTITEXCOORD2FVARBPROC glMultiTexCoord2fvARB;
+PFNGLACTIVETEXTUREARBPROC    glActiveTextureARB   ;
 
 #endif
 
