@@ -1100,10 +1100,10 @@ def export(filename):
             for i in range(len(face.v)):
               vertex = vertices.get(face.v[i].index)
               if not vertex:
-                coord  = point_by_matrix (face.v[i].co, matrix)
+                coord    = point_by_matrix (face.v[i].co, matrix)
                 if face.smooth:
                   normal = vector_normalize(vector_by_matrix(face.v[i].no, matrix))
-                vertex  = vertices[face.v[i].index] = Vertex(submesh, coord, normal)
+                vertex   = vertices[face.v[i].index] = Vertex(submesh, coord, normal)
                 
                 influences = data.getVertexInfluences(face.v[i].index)
                 # should this really be a warning? (well currently enabled,
@@ -1328,6 +1328,11 @@ def export(filename):
     for glob_param in glob_params:
       print >> cfg, glob_param
   except: pass
+  
+  # Remove soya cached data -- they need to be re-computed, since the model have changed
+  for filename in os.listdir(DIRNAME):
+    if filename.startswith("neighbors"):
+      os.remove(os.path.join(DIRNAME, filename))
       
   log.info("Saved to '%s.cfg'" % BASENAME)
   log.info("Done.")
