@@ -200,6 +200,18 @@ def pointbymatrix(p, m):
           p[0] * m[0][2] + p[1] * m[1][2] + p[2] * m[2][2] + m[3][2]]
 
 
+def get_material(filename):
+  try: return soya.Material.get(filename)
+  except ImportError:
+    print "Warning, you are running Blender's Python, which does not have PIL !"
+    print "I'm trying to run system python..."
+    path = str(soya.path)
+    r = os.system("""python -c "import soya; soya.path = %s; soya.Material.get('%s')" """ % (path, filename))
+    if r: print "Failed -- Please install PIL (Python Imaging Library)"
+    else:
+      print "OK !"
+      return soya.Material.get(filename)
+    
 class Blender2Soya:
   def __init__(self, **args):
     self.use_global_args()
@@ -316,7 +328,7 @@ class Blender2Soya:
             image_filename    = face.image.name
             material_filename = image_filename[:image_filename.rfind(".")]
             material_filename = self.materials_map.get(material_filename, material_filename)
-            f.material = soya.Material.get(material_filename)
+            f.material = get_material(material_filename)
             
             
     if nb_points_and_lines:
@@ -335,7 +347,7 @@ class Blender2Soya:
       
     if self.cellshading:
       root_world.shapifier = soya.CellShadingShapifier(
-        shader              = (self.cellshading_shader and soya.Material.get(self.cellshading_shader)) or None,
+        shader              = (self.cellshading_shader and get_material(self.cellshading_shader)) or None,
         outline_color       = self.cellshading_outline_color,
         outline_width       = self.cellshading_outline_width,
         outline_attenuation = self.cellshading_outline_attenuation,
