@@ -15,5 +15,9 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+
+import warnings
+warnings.warn("The content of this module is now in the soya module.", DeprecationWarning)
+
 from soya import Land
 
