@@ -27,7 +27,7 @@
 #include <stdarg.h>
 #include <float.h>
 #include <math.h>
-#include <GL/gl.h>
+#include <GL/glew.h>
 
 #include "matrix.h"
 
@@ -1528,13 +1528,13 @@ void face_intersect_plane (GLfloat* face, int nbpoints, GLfloat plane[4], GLfloa
 }
 
 void face_cut_by_plane (GLfloat* face, int nbpoints, GLfloat plane[4], GLfloat** freturn1, GLfloat** freturn2, int* nbreturn1, int* nbreturn2) {
-  if (nbpoints == 0) { return; }
   int i; int j; int k; int l;
   int side = 0;
   GLfloat* vs = (GLfloat*) malloc (nbpoints * sizeof (GLfloat));
   GLfloat v[3];
   GLfloat inter[3];
   GLfloat f;
+  if (nbpoints == 0) { return; }
   
   freturn1[0] = NULL;
   freturn2[0] = NULL;
@@ -2028,65 +2028,3 @@ void frustum_to_box (Frustum* frustum, GLfloat* box) {
   }
 }
 
-Frustum* C_frustum_coordsyst_into (Frustum* r, Frustum* f, GLfloat* old, GLfloat* new) {
-  printf("zz");
-  GLfloat* matrix = NULL;
-  GLfloat scalefactor[3] = { 1.0, 1.0, 1.0 };
-  GLfloat scaling;
-  int i;
-  printf("z");
-  if (r == NULL) {
-    /* return a new frustum */
-    r = (Frustum*) malloc (sizeof (Frustum));
-  }
-  
-  printf("a");
-  
-  /* clone */
-  memcpy (r, f, sizeof (Frustum));
-  if (new != old) {
-    /* change position, points of coordsys */
-    if (old != NULL) {
-      for (i = 0; i < 24; i += 3) { point_by_matrix (r->points + i, old); }
-      scalefactor[0] *= matrix[16];
-      scalefactor[1] *= matrix[17];
-      scalefactor[2] *= matrix[18];
-      point_by_matrix (r->position, matrix);
-    }
-  printf("b");
-    if (new != NULL) {
-      for (i = 0; i < 24; i += 3) { point_by_matrix (r->points + i, matrix); }
-      scalefactor[0] *= matrix[16];
-      scalefactor[1] *= matrix[17];
-      scalefactor[2] *= matrix[18];
-      point_by_matrix (r->position, matrix); 
-    }
-  printf("c");
-    /* re-compute the normals */
-    scaling = scalefactor[0];
-    if (scalefactor[1] > scaling) { scaling = scalefactor[1]; }
-    if (scalefactor[2] > scaling) { scaling = scalefactor[2]; }
-    face_normal (r->planes, r->points, r->points + 3, r->points + 9);
-    vector_set_length (r->planes, scaling);
-    face_normal (r->planes + 4, r->points + 12, r->points + 15, r->points);
-    vector_set_length (r->planes + 4, scaling);
-    face_normal (r->planes + 8, r->points + 9, r->points + 6, r->points + 21);
-    vector_set_length (r->planes + 8, scaling);
-    face_normal (r->planes + 12, r->points + 12, r->points, r->points + 21);
-    vector_set_length (r->planes + 12, scaling);
-    face_normal (r->planes + 16, r->points + 3, r->points + 15, r->points + 6);
-    vector_set_length (r->planes + 16, scaling);
-    face_normal (r->planes + 20, r->points + 15, r->points + 12, r->points + 18);
-    vector_set_length (r->planes + 20, scaling);
-  printf("d");
-    /* re-compute the constants */
-    r->planes[ 3] = -(r->planes[ 0] * r->points[ 0] + r->planes[ 1] * r->points[ 1] + r->planes[ 2] * r->points[ 2]);
-    r->planes[ 7] = -(r->planes[ 4] * r->points[ 0] + r->planes[ 5] * r->points[ 1] + r->planes[ 6] * r->points[ 2]);
-    r->planes[11] = -(r->planes[ 8] * r->points[ 6] + r->planes[ 9] * r->points[ 7] + r->planes[10] * r->points[ 8]);
-    r->planes[15] = -(r->planes[12] * r->points[ 0] + r->planes[13] * r->points[ 1] + r->planes[14] * r->points[ 2]);
-    r->planes[19] = -(r->planes[16] * r->points[ 6] + r->planes[17] * r->points[ 7] + r->planes[18] * r->points[ 8]);
-    r->planes[23] = -(r->planes[20] * r->points[12] + r->planes[21] * r->points[13] + r->planes[22] * r->points[14]);
-  }
-  printf("e");
-  return r;
-}
