@@ -1,4 +1,4 @@
-# PyOpenAl
+# Soya
 # Copyright (C) 2003 Jean-Baptiste LAMY -- jiba@tuxfamily.org
 #
 # This program is free software; you can redistribute it and/or modify
@@ -52,19 +52,27 @@ it is not required that it is a Camera, though it is usually one."""
   
   global _LISTENER, _CAMERA, _INITED
   if not _INITED:
+    soya.BEFORE_RENDER.append(render)
     pyopenal.init()
     if not _LISTENER:
-      _LISTENER          = Listener(freq)
-      _LISTENER.position = (0.0, 0.0,  0.0)
-      _LISTENER.at       = (0.0, 0.0, -1.0)
-      _LISTENER.up       = (0.0, 1.0,  0.0)
-    _INITED = 1
+      try:
+        _LISTENER          = Listener(freq)
+        _LISTENER.position = (0.0, 0.0,  0.0)
+        _LISTENER.at       = (0.0, 0.0, -1.0)
+        _LISTENER.up       = (0.0, 1.0,  0.0)
+        _INITED = 1
+      except:
+        print "Can't create listener for audio device, sound will be disabled"
     
   _CAMERA = camera
 
 _SOURCES_POS_SPEED = []
 _PENDING = []
 
+DISTANCE_ATTENUATION  = 7.0
+DOPPLER_EFFECT_FACTOR = 1.0
+DOPPLER_EFFECT_FACTOR = 0.0001
+
 def preload_sound(filename, async = 0):
   """Pre-load sound FILENAME, in order to be able to play it immediately later.
 If ASYNC, the sound is pre-loaded in an other thread.
@@ -98,6 +106,10 @@ uncompress).
 FILENAME can be Wave or Ogg Vorbis file (need PyOgg and PyVorbis) ; the file
 is searched in {soya.path}/sounds/."""
 
+  # Exit when sound not initialized
+  if not _INITED:
+    return
+  
   buffer = _BUFFERS.get(filename)
   if not buffer:
     if async:
@@ -114,7 +126,7 @@ is searched in {soya.path}/sounds/."""
   source          = Source()
   source.buffer   = buffer
   source.looping  = looping
-  source.gain     = gain
+  source.gain     = gain * 20.0 # This is to keep a similar volume level with soya.sdl_mixer4soya
   
   _SOURCES_POS_SPEED.append((source, position, speed))
   
@@ -128,8 +140,10 @@ is searched in {soya.path}/sounds/."""
   
   return source
 
-
 def _play_async(source, filename, position, speed, gain):
+  # Exit when sound not initialized
+  if not _INITED:
+    return
   os.nice(5)
   if   filename.endswith(".wav"): format, data, freq = wave_data      (find_file_in_path(filename))
   elif filename.endswith(".ogg"): format, data, freq = ogg_vorbis_data(find_file_in_path(filename))
@@ -147,10 +161,9 @@ class _AsyncSource(Source):
 
 import time
 
-DOPPLER_EFFECT_FACTOR = 1 / 100.0
 _LAST_TIME = time.time()
-def _render():
-  """_render()
+def render():
+  """render()
 
 Update the sources's positions and speed.
 
@@ -170,7 +183,13 @@ This function is called before each Soya rendering."""
       i += 1
       if position:
         oldpos = source.position
-        source.position = pos = _CAMERA.transform(position)
+        pos    = _CAMERA.transform(position)
+        pos    = (
+          pos[0] * DISTANCE_ATTENUATION,
+          pos[1] * DISTANCE_ATTENUATION,
+          pos[2] * DISTANCE_ATTENUATION,
+          )
+        source.position = pos
         if speed:
           source.velocity = _CAMERA.transform(speed)
         elif dt:
@@ -198,9 +217,3 @@ This function is called before each Soya rendering."""
     if not source.canceled: source.play()
     
     
-_old_render = soya.render
-def render():
-  _render()
-  _old_render()
-
-soya.render = render
